open Analyze
open Translate
open Programname
open Sys

type action = Syntax | Analyze | Translate | Comp

let contents = ref ""
let () =
  let file = (open_in "stdlib.fogl") in
  try
    while true do
      let line = input_line file in
      contents := !contents ^ line ^ "\n"
    done
  with End_of_file ->
    let file = (open_in Sys.argv.(2)) in
    try
	  while true do
	    let line = input_line file in
	    contents := !contents ^ line ^ "\n"
	  done
    with End_of_file -> ()

let _ =
  let action = if Array.length Sys.argv > 1 then
    List.assoc Sys.argv.(1) [ ("-s", Syntax);
			      ("-a", Analyze);
			      ("-t", Translate);
			      ("-c", Comp) ]
  else Comp in
  let lexbuf = Lexing.from_string !contents in
  let program = Parser.program Scanner.token lexbuf in

  let translate_prog _ = 
	(if (Sys.file_exists Translate.dir) then
	    ignore(Sys.command("rm -rf " ^ Translate.dir))
	else
		());
	ignore (Sys.command("mkdir " ^ Translate.dir));
	ignore (Sys.command("cp -r Java/* " ^ Translate.dir));
	(Translate.tr_program program 
	    (Analyze.makeTable program) 0)

  in

  match action with
    Syntax -> print_endline "Syntax: Valid"
  | Analyze -> let scopes = (Analyze.makeTable program) in
	print_endline ("Analyze: Valid\n" ^ Strings.of_scopes scopes)
  | Translate ->  
	translate_prog();
	print_endline ("JavaGenerate: Completed.\n")  
  | Comp -> 

    let com src = 
	"javac -Xlint:none " ^ src ^ "*/*.java" in
    (*
	"javac " ^ src ^"Main/*.java "^ src ^ "Stdlib/*.java " 
	^src^"GeneratedCode/*.java "^src^
	"Type/*.java " ^ src ^ "BuiltIns/*.java" in
	*)

    let main_cls src = src ^ "Main/Animation" in
    let clss src = src ^ "Main/*.class " ^ src ^ "Stdlib/*.class "
	^ src ^ "BuiltIns/*.class " ^  src ^ "GeneratedCode/*.class "
	^ src ^ "Type/*.class"
    in
    let jar src = "jar cfe " ^ 
	Programname.get_name ^ ".jar " ^ (main_cls src)^ " "
	    ^ (clss src) in

	translate_prog();
	ignore (Sys.command (com Translate.dir));
	ignore (Sys.command ("cp -r " ^ Translate.dir ^ "*" ^ " ./"));
	ignore (Sys.command (jar ""));
	ignore (Sys.command ("rm -rf Type Main Stdlib BuiltIns GeneratedCode"))
